==> zio-aws-redshift_2.13-5.17.145.1-sources.jar: zio/aws/redshift/model/ModifyEventSubscriptionRequest.scala <==
package zio.aws.redshift.model
import zio.aws.redshift.model.primitives.BooleanOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ModifyEventSubscriptionRequest(
    subscriptionName: String,
    snsTopicArn: Option[String] = None,
    sourceType: Option[String] = None,
    sourceIds: Option[Iterable[String]] = None,
    eventCategories: Option[Iterable[String]] = None,
    severity: Option[String] = None,
    enabled: Option[BooleanOptional] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.ModifyEventSubscriptionRequest = {
    import ModifyEventSubscriptionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.ModifyEventSubscriptionRequest
      .builder()
      .subscriptionName(subscriptionName: java.lang.String)
      .optionallyWith(snsTopicArn.map(value => value: java.lang.String))(
        _.snsTopicArn
      )
      .optionallyWith(sourceType.map(value => value: java.lang.String))(
        _.sourceType
      )
      .optionallyWith(
        sourceIds.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.sourceIds)
      .optionallyWith(
        eventCategories.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.eventCategories)
      .optionallyWith(severity.map(value => value: java.lang.String))(
        _.severity
      )
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .build()
  }
  def asReadOnly
      : zio.aws.redshift.model.ModifyEventSubscriptionRequest.ReadOnly =
    zio.aws.redshift.model.ModifyEventSubscriptionRequest.wrap(buildAwsValue())
}
object ModifyEventSubscriptionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.ModifyEventSubscriptionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.ModifyEventSubscriptionRequest =
      zio.aws.redshift.model.ModifyEventSubscriptionRequest(
        subscriptionName,
        snsTopicArn.map(value => value),
        sourceType.map(value => value),
        sourceIds.map(value => value),
        eventCategories.map(value => value),
        severity.map(value => value),
        enabled.map(value => value)
      )
    def subscriptionName: String
    def snsTopicArn: Option[String]
    def sourceType: Option[String]
    def sourceIds: Option[List[String]]
    def eventCategories: Option[List[String]]
    def severity: Option[String]
    def enabled: Option[BooleanOptional]
    def getSubscriptionName: ZIO[Any, Nothing, String] =
      ZIO.succeed(subscriptionName)
    def getSnsTopicArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("snsTopicArn", snsTopicArn)
    def getSourceType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("sourceType", sourceType)
    def getSourceIds: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("sourceIds", sourceIds)
    def getEventCategories: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("eventCategories", eventCategories)
    def getSeverity: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("severity", severity)
    def getEnabled: ZIO[Any, AwsError, BooleanOptional] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.ModifyEventSubscriptionRequest
  ) extends zio.aws.redshift.model.ModifyEventSubscriptionRequest.ReadOnly {
    override val subscriptionName: String = impl.subscriptionName(): String
    override val snsTopicArn: Option[String] =
      scala.Option(impl.snsTopicArn()).map(value => value: String)
    override val sourceType: Option[String] =
      scala.Option(impl.sourceType()).map(value => value: String)
    override val sourceIds: Option[List[String]] = scala
      .Option(impl.sourceIds())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val eventCategories: Option[List[String]] = scala
      .Option(impl.eventCategories())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val severity: Option[String] =
      scala.Option(impl.severity()).map(value => value: String)
    override val enabled: Option[BooleanOptional] =
      scala.Option(impl.enabled()).map(value => value: BooleanOptional)
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.ModifyEventSubscriptionRequest
  ): zio.aws.redshift.model.ModifyEventSubscriptionRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-redshift_3-5.17.130.3-sources.jar: zio/aws/redshift/model/ModifyEventSubscriptionRequest.scala <==
package zio.aws.redshift.model
import zio.aws.redshift.model.primitives.BooleanOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ModifyEventSubscriptionRequest(
    subscriptionName: String,
    snsTopicArn: Option[String] = None,
    sourceType: Option[String] = None,
    sourceIds: Option[Iterable[String]] = None,
    eventCategories: Option[Iterable[String]] = None,
    severity: Option[String] = None,
    enabled: Option[BooleanOptional] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.redshift.model.ModifyEventSubscriptionRequest = {
    import ModifyEventSubscriptionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.redshift.model.ModifyEventSubscriptionRequest
      .builder()
      .subscriptionName(subscriptionName: java.lang.String)
      .optionallyWith(snsTopicArn.map(value => value: java.lang.String))(
        _.snsTopicArn
      )
      .optionallyWith(sourceType.map(value => value: java.lang.String))(
        _.sourceType
      )
      .optionallyWith(
        sourceIds.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.sourceIds)
      .optionallyWith(
        eventCategories.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.eventCategories)
      .optionallyWith(severity.map(value => value: java.lang.String))(
        _.severity
      )
      .optionallyWith(
        enabled.map(value => BooleanOptional.unwrap(value): java.lang.Boolean)
      )(_.enabled)
      .build()
  }
  def asReadOnly
      : zio.aws.redshift.model.ModifyEventSubscriptionRequest.ReadOnly =
    zio.aws.redshift.model.ModifyEventSubscriptionRequest.wrap(buildAwsValue())
}
object ModifyEventSubscriptionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.redshift.model.ModifyEventSubscriptionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.redshift.model.ModifyEventSubscriptionRequest =
      zio.aws.redshift.model.ModifyEventSubscriptionRequest(
        subscriptionName,
        snsTopicArn.map(value => value),
        sourceType.map(value => value),
        sourceIds.map(value => value),
        eventCategories.map(value => value),
        severity.map(value => value),
        enabled.map(value => value)
      )
    def subscriptionName: String
    def snsTopicArn: Option[String]
    def sourceType: Option[String]
    def sourceIds: Option[List[String]]
    def eventCategories: Option[List[String]]
    def severity: Option[String]
    def enabled: Option[BooleanOptional]
    def getSubscriptionName: ZIO[Any, Nothing, String] =
      ZIO.succeed(subscriptionName)
    def getSnsTopicArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("snsTopicArn", snsTopicArn)
    def getSourceType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("sourceType", sourceType)
    def getSourceIds: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("sourceIds", sourceIds)
    def getEventCategories: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("eventCategories", eventCategories)
    def getSeverity: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("severity", severity)
    def getEnabled: ZIO[Any, AwsError, BooleanOptional] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.redshift.model.ModifyEventSubscriptionRequest
  ) extends zio.aws.redshift.model.ModifyEventSubscriptionRequest.ReadOnly {
    override val subscriptionName: String = impl.subscriptionName(): String
    override val snsTopicArn: Option[String] =
      scala.Option(impl.snsTopicArn()).map(value => value: String)
    override val sourceType: Option[String] =
      scala.Option(impl.sourceType()).map(value => value: String)
    override val sourceIds: Option[List[String]] = scala
      .Option(impl.sourceIds())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val eventCategories: Option[List[String]] = scala
      .Option(impl.eventCategories())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val severity: Option[String] =
      scala.Option(impl.severity()).map(value => value: String)
    override val enabled: Option[BooleanOptional] = scala
      .Option(impl.enabled())
      .map(value => zio.aws.redshift.model.primitives.BooleanOptional(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.redshift.model.ModifyEventSubscriptionRequest
  ): zio.aws.redshift.model.ModifyEventSubscriptionRequest.ReadOnly =
    new Wrapper(impl)
}
